package com.sun.org.apache.xml.internal.security.keys.keyresolver;

import javax.xml.parsers.ParserConfigurationException;
import java.io.IOException;
import org.xml.sax.SAXException;
import com.sun.org.apache.xml.internal.security.utils.XMLUtils;
import java.io.ByteArrayInputStream;
import java.util.HashMap;
import java.security.PrivateKey;
import javax.crypto.SecretKey;
import java.security.cert.X509Certificate;
import java.security.PublicKey;
import com.sun.org.apache.xml.internal.security.keys.storage.StorageResolver;
import org.w3c.dom.Element;
import java.util.Map;

public abstract class KeyResolverSpi
{
    protected Map<String, String> properties;
    protected boolean globalResolver;
    protected boolean secureValidation;
    
    public KeyResolverSpi() {
        this.globalResolver = false;
    }
    
    public void setSecureValidation(boolean secureValidation) {
        this.secureValidation = secureValidation;
    }
    
    public boolean engineCanResolve(Element element, String s, StorageResolver storageResolver) {
        throw new UnsupportedOperationException();
    }
    
    public PublicKey engineResolvePublicKey(Element element, String s, StorageResolver storageResolver) throws KeyResolverException {
        throw new UnsupportedOperationException();
    }
    
    public PublicKey engineLookupAndResolvePublicKey(Element element, String s, StorageResolver storageResolver) throws KeyResolverException {
        KeyResolverSpi cloneIfNeeded = this.cloneIfNeeded();
        if (!cloneIfNeeded.engineCanResolve(element, s, storageResolver)) {
            return null;
        }
        return cloneIfNeeded.engineResolvePublicKey(element, s, storageResolver);
    }
    
    private KeyResolverSpi cloneIfNeeded() throws KeyResolverException {
        if (this.globalResolver) {
            try {
                return (KeyResolverSpi)this.getClass().newInstance();
            }
            catch (InstantiationException ex) {
                throw new KeyResolverException(ex, "");
            }
            catch (IllegalAccessException ex2) {
                throw new KeyResolverException(ex2, "");
            }
        }
        else {
            return this;
        }
    }
    
    public X509Certificate engineResolveX509Certificate(Element element, String s, StorageResolver storageResolver) throws KeyResolverException {
        throw new UnsupportedOperationException();
    }
    
    public X509Certificate engineLookupResolveX509Certificate(Element element, String s, StorageResolver storageResolver) throws KeyResolverException {
        KeyResolverSpi cloneIfNeeded = this.cloneIfNeeded();
        if (!cloneIfNeeded.engineCanResolve(element, s, storageResolver)) {
            return null;
        }
        return cloneIfNeeded.engineResolveX509Certificate(element, s, storageResolver);
    }
    
    public SecretKey engineResolveSecretKey(Element element, String s, StorageResolver storageResolver) throws KeyResolverException {
        throw new UnsupportedOperationException();
    }
    
    public SecretKey engineLookupAndResolveSecretKey(Element element, String s, StorageResolver storageResolver) throws KeyResolverException {
        KeyResolverSpi cloneIfNeeded = this.cloneIfNeeded();
        if (!cloneIfNeeded.engineCanResolve(element, s, storageResolver)) {
            return null;
        }
        return cloneIfNeeded.engineResolveSecretKey(element, s, storageResolver);
    }
    
    public PrivateKey engineLookupAndResolvePrivateKey(Element element, String s, StorageResolver storageResolver) throws KeyResolverException {
        return null;
    }
    
    public void engineSetProperty(String s, String s2) {
        if (this.properties == null) {
            this.properties = new HashMap();
        }
        this.properties.put(s, s2);
    }
    
    public String engineGetProperty(String s) {
        if (this.properties == null) {
            return null;
        }
        return (String)this.properties.get(s);
    }
    
    public boolean understandsProperty(String s) {
        return this.properties != null && this.properties.get(s) != null;
    }
    
    public void setGlobalResolver(boolean globalResolver) {
        this.globalResolver = globalResolver;
    }
    
    protected static Element getDocFromBytes(byte[] buf, boolean b) throws KeyResolverException {
        try (final ByteArrayInputStream is = new ByteArrayInputStream(buf)) {
            return XMLUtils.createDocumentBuilder(false, b).parse(is).getDocumentElement();
        }
        catch (SAXException ex) {
            throw new KeyResolverException(ex);
        }
        catch (IOException ex2) {
            throw new KeyResolverException(ex2);
        }
        catch (ParserConfigurationException ex3) {
            throw new KeyResolverException(ex3);
        }
    }
}
